==> haskell-reducers-3.12.3-194-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-reducers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 reducers
version:              3.12.3
visibility:           public
id:                   reducers-3.12.3-A3oVmHZF07SD4vFk6uqko7
key:                  reducers-3.12.3-A3oVmHZF07SD4vFk6uqko7
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/reducers/
synopsis:
    Semigroups, specialized containers and a general map/reduce framework

description:
    Semigroups, specialized containers and a general map/reduce framework.

category:             Data, Math, Numerical, Semigroups
abi:                  c98f4546c6d693073ce104b91ba97442
exposed:              True
exposed-modules:
    Data.Generator Data.Generator.Combinators Data.Semigroup.Alt
    Data.Semigroup.Alternative Data.Semigroup.Applicative
    Data.Semigroup.Apply Data.Semigroup.Generator
    Data.Semigroup.Instances Data.Semigroup.Monad
    Data.Semigroup.MonadPlus Data.Semigroup.Reducer
    Data.Semigroup.Reducer.With Data.Semigroup.Self
    Data.Semigroup.Union

import-dirs:          /usr/lib/ghc-9.0.1/site-local/reducers-3.12.3
library-dirs:         /usr/lib/ghc-9.0.1/site-local/reducers-3.12.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/reducers-3.12.3
hs-libraries:         HSreducers-3.12.3-A3oVmHZF07SD4vFk6uqko7
depends:
    array-0.5.4.0 base-4.15.0.0 bytestring-0.10.12.1 containers-0.6.4.1
    fingertree-0.1.4.2-40nr4eXmNsYGlQ946OL9p8
    hashable-1.3.2.0-GcuYQ7tqoHiC8dylGWZgv9
    semigroupoids-5.3.5-5LKavgnM75J3u3sYkbNOdz text-1.2.4.1
    transformers-0.5.6.2
    unordered-containers-0.2.14.0-GZb439Gbt7L1ozynZzbOaU

haddock-interfaces:   /usr/share/doc/haskell-reducers/html/reducers.haddock
haddock-html:         /usr/share/doc/haskell-reducers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-reducers-3.12.3-200-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-reducers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 reducers
version:              3.12.3
visibility:           public
id:                   reducers-3.12.3-1BdoCigfunNJf17eitrMcn
key:                  reducers-3.12.3-1BdoCigfunNJf17eitrMcn
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/reducers/
synopsis:
    Semigroups, specialized containers and a general map/reduce framework

description:
    Semigroups, specialized containers and a general map/reduce framework.

category:             Data, Math, Numerical, Semigroups
abi:                  f14c154861db0596f636026e61d7c40f
exposed:              True
exposed-modules:
    Data.Generator Data.Generator.Combinators Data.Semigroup.Alt
    Data.Semigroup.Alternative Data.Semigroup.Applicative
    Data.Semigroup.Apply Data.Semigroup.Generator
    Data.Semigroup.Instances Data.Semigroup.Monad
    Data.Semigroup.MonadPlus Data.Semigroup.Reducer
    Data.Semigroup.Reducer.With Data.Semigroup.Self
    Data.Semigroup.Union

import-dirs:          /usr/lib/ghc-9.0.1/site-local/reducers-3.12.3
library-dirs:         /usr/lib/ghc-9.0.1/site-local/reducers-3.12.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/reducers-3.12.3
hs-libraries:         HSreducers-3.12.3-1BdoCigfunNJf17eitrMcn
depends:
    array-0.5.4.0 base-4.15.0.0 bytestring-0.10.12.1 containers-0.6.4.1
    fingertree-0.1.4.2-L86zjCbIHrf9IxYcPJav85
    hashable-1.3.2.0-2579b4ed8EpGiVuNwiQjKE
    semigroupoids-5.3.5-HXBtEdHlc3rJZTpH0VHqFx text-1.2.4.1
    transformers-0.5.6.2
    unordered-containers-0.2.14.0-9dFFYFCso8sGtsfFV1YYEC

haddock-interfaces:   /usr/share/doc/haskell-reducers/html/reducers.haddock
haddock-html:         /usr/share/doc/haskell-reducers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
